Welcome to ClientVPS Mirrors

Help for package greencrab.toolkit
Title: Run 'Stan' Models to Interpret Green Crab Monitoring Assessments
Version: 0.2
Maintainer: Abigail G. Keller <agkeller@berkeley.edu>
Description: These Bayesian models written in the 'Stan' probabilistic language can be used to interpret green crab trapping and environmental DNA monitoring data, either independently or jointly. Detailed model information is found in Keller (2022) <doi:10.1002/eap.2561>.
License: GPL-3
Encoding: UTF-8
RoxygenNote: 7.2.3
Biarch: true
Depends: R (≥ 3.4.0)
Imports: Rcpp (≥ 0.12.0), RcppParallel (≥ 5.0.1), rstan (≥ 2.26.23), rstantools (≥ 2.2.0), methods
LinkingTo: BH (≥ 1.66.0), Rcpp (≥ 0.12.0), RcppEigen (≥ 0.3.3.3.0), RcppParallel (≥ 5.0.1), rstan (≥ 2.26.23), StanHeaders (≥ 2.26.22)
SystemRequirements: GNU make
NeedsCompilation: yes
Packaged: 2023-09-11 15:57:49 UTC; abby
Author: Abigail G. Keller [aut, cre]
Repository: CRAN
Date/Publication: 2023-09-12 21:10:02 UTC

The 'greencrab.toolkit' package.

Description

These Bayesian models written in the 'Stan' probabilistic language can be used to interpret green crab trapping and environmental DNA monitoring data, either independently or jointly. Detailed model information is found in Keller (2022) <doi:10.1002/eap.2561>.

References

Stan Development Team (2023). RStan: the R interface to Stan. R package version 2.21.8. https://mc-stan.org

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.